@@ -185,9 +185,10 @@ OC.L10N.register(
     "Members" : "Členové",
     "Upload new files" : "Nahrát nové soubory",
     "Share from Files" : "Sdílet ze Souborů",
+    "Pending share" : "Čekající sdílení",
     "Add this attachment" : "Přidat tuto přílohu",
     "Show in Files" : "Zobrazit v Souborech",
-    "Unshare file" : "Přestat sdílet soubor",
+    "Remove attachment" : "Odebrat přílohu",
     "Delete Attachment" : "Smazat přílohu",
     "Restore Attachment" : "Obnovit přílohu",
     "File to share" : "Soubor ke sdílení",
@@ -209,6 +210,10 @@ OC.L10N.register(
     "Set a due date" : "Vybrat termín",
     "Remove due date" : "Odstranit termín",
     "Select Date" : "Vybrat datum",
+    "Today" : "Dnes",
+    "Tomorrow" : "Zítra",
+    "Next week" : "Příští týden",
+    "Next month" : "Příští měsíc",
     "Save" : "Uložit",
     "The comment cannot be empty." : "Komentář je třeba vyplnit.",
     "The comment cannot be longer than 1000 characters." : "Délka komentáře může být nejvýše 1 000 znaků.",
@@ -262,8 +267,6 @@ OC.L10N.register(
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Opravdu chcete tabuly {title} smazat? Toto smaže veškerá data této tabule.",
     "Delete the board?" : "Smazat tabuli?",
     "Loading filtered view" : "Načítání filtrovaného pohledu",
-    "Today" : "Dnes",
-    "Tomorrow" : "Zítra",
     "This week" : "Tento týden",
     "No due" : "Žádný termín",
     "Search for {searchQuery} in all boards" : "Hledat {searchQuery} na všech tabulích",
